package com.yijia.customer.controller;

import java.util.ArrayList;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yijia.common.constant.HttpStatus;
import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.system.service.ISysDeptService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.customer.domain.CustomerElectronicCard;
import com.yijia.customer.service.ICustomerElectronicCardService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 客户电子会员卡（储蓄卡）Controller
 * 
 * @author yijia
 * @date 2021-04-12
 */
@RestController
@RequestMapping("/customer/card")
public class CustomerElectronicCardController extends BaseController
{
    @Autowired
    private ICustomerElectronicCardService customerElectronicCardService;

    @Autowired
    private ISysDeptService deptService;
    /**
     * 查询客户电子会员卡（储蓄卡）列表
     */
    @PreAuthorize("@ss.hasPermi('customer:card:list')")
    @GetMapping("/list")
    public TableDataInfo list(CustomerElectronicCard customerElectronicCard)
    {
        if(customerElectronicCard!=null &&customerElectronicCard.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerElectronicCard.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerElectronicCard.setStationIdList(list);
            customerElectronicCard.setStationId(null);
        }
        startPage();
        List<CustomerElectronicCard> list = customerElectronicCardService.selectCustomerElectronicCardList(customerElectronicCard);
        return getDataTable(list);
    }

    /**
     * 导出客户电子会员卡（储蓄卡）列表
     */
    @PreAuthorize("@ss.hasPermi('customer:card:export')")
    @Log(title = "客户电子会员卡（储蓄卡）", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CustomerElectronicCard customerElectronicCard)
    {
        List<CustomerElectronicCard> list = customerElectronicCardService.selectCustomerElectronicCardList(customerElectronicCard);
        ExcelUtil<CustomerElectronicCard> util = new ExcelUtil<CustomerElectronicCard>(CustomerElectronicCard.class);
        return util.exportExcel(list, "card");
    }

    /**
     * 获取客户电子会员卡（储蓄卡）详细信息
     */
    @PreAuthorize("@ss.hasPermi('customer:card:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(customerElectronicCardService.selectCustomerElectronicCardById(id));
    }

    /**
     * 新增客户电子会员卡（储蓄卡）
     */
    @PreAuthorize("@ss.hasPermi('customer:card:add')")
    @Log(title = "客户电子会员卡（储蓄卡）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerElectronicCard customerElectronicCard)
    {
        return toAjax(customerElectronicCardService.insertCustomerElectronicCard(customerElectronicCard));
    }

    /**
     * 修改客户电子会员卡（储蓄卡）
     */
    @PreAuthorize("@ss.hasPermi('customer:card:edit')")
    @Log(title = "客户电子会员卡（储蓄卡）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerElectronicCard customerElectronicCard)
    {
        return toAjax(customerElectronicCardService.updateCustomerElectronicCard(customerElectronicCard));
    }

    /**
     * 删除客户电子会员卡（储蓄卡）
     */
    @PreAuthorize("@ss.hasPermi('customer:card:remove')")
    @Log(title = "客户电子会员卡（储蓄卡）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(customerElectronicCardService.deleteCustomerElectronicCardByIds(ids));
    }
    /**
     * 查询电子会员数据
     */
    @PreAuthorize("@ss.hasPermi('customer:card:listSum')")
    @GetMapping("/listSum")
    public AjaxResult listSum(CustomerElectronicCard customerElectronicCard)
    {
        if(customerElectronicCard!=null &&customerElectronicCard.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerElectronicCard.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerElectronicCard.setStationIdList(list);
            customerElectronicCard.setStationId(null);
        }
        return AjaxResult.success(customerElectronicCardService.listSum(customerElectronicCard));
    }

    @PreAuthorize("@ss.hasPermi('customer:card:selectCard')")
    @GetMapping("/selectCard")
    public TableDataInfo selectCard(CustomerElectronicCard customerElectronicCard)
    {
        if(customerElectronicCard!=null &&customerElectronicCard.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerElectronicCard.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerElectronicCard.setStationIdList(list);
            customerElectronicCard.setStrSql(StringUtils.join(list, ","));
            customerElectronicCard.setStationId(null);
        }
       // startPage();
        List<CustomerElectronicCard>  querylist= customerElectronicCardService.selectCard(customerElectronicCard) ;
        List<CustomerElectronicCard> pagelist = customerElectronicCardService.selectCardPage(customerElectronicCard) ;
       //TableDataInfo  ss =getDataPageTable(querylist,pagelist);
//        PageInfo<CustomerElectronicCard> pageInfo= new PageInfo<CustomerElectronicCard>(querylist,customerElectronicCard.getPageSetting());
        TableDataInfo rspData = new TableDataInfo();
        rspData.setCode(HttpStatus.SUCCESS);
        rspData.setMsg("查询成功");
//        List<CustomerElectronicCard>  querylist= new ArrayList<>();
        rspData.setRows(querylist);
        rspData.setTotal(pagelist.size());
        return rspData;
    }
    /**
     * 查询电子会员数据
     */
    @PreAuthorize("@ss.hasPermi('customer:card:listHYData')")
    @GetMapping("/listHYData")
    public AjaxResult listHYData(CustomerElectronicCard customerElectronicCard)
    {
        if(customerElectronicCard!=null &&customerElectronicCard.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerElectronicCard.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerElectronicCard.setStationIdList(list);
            customerElectronicCard.setStationId(null);
        }
        return AjaxResult.success(customerElectronicCardService.listHYData(customerElectronicCard));
    }

    /**
     * 查询电子会员数据
     */
    @PreAuthorize("@ss.hasPermi('customer:card:listJRHYData')")
    @GetMapping("/listJRHYData")
    public AjaxResult listJRHYData(CustomerElectronicCard customerElectronicCard)
    {
        if(customerElectronicCard!=null &&customerElectronicCard.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerElectronicCard.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerElectronicCard.setStationIdList(list);
            customerElectronicCard.setStationId(null);
        }
        return AjaxResult.success(customerElectronicCardService.listJRHYData(customerElectronicCard));
    }
}
